/*
 *   Wireless Access Point SNMP Utilites for Linux
 * 
 *   Copyright (c) 2002 Roman Festchook <roma at polesye dot net>
 * 
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License Version 2 from
 *   June 1991 as published by the Free Software Foundation.
 * 
 *   This program is distributed in the hope that it will be useful, but
 *   WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License along
 *   with this program; if not, write to the Free Software Foundation, Inc.,
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/* Define if no regulation domain restrictions */
#undef NO_REG_DOMAIN

/* Define if OS Linux */
#undef OS_LINUX

/* Define if OS OpenBSD */
#undef OS_BSD
